@@ -12,7 +12,8 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.model.policy import create_policy_check
 from tiddlyweb.store import NoBagError, StoreMethodNotImplemented
-from tiddlyweb.serializer import Serializer, NoSerializationError, BagFormatError
+from tiddlyweb.serializer import (Serializer, NoSerializationError,
+        BagFormatError)
 from tiddlyweb.web import util as web
 from tiddlyweb.web.sendentity import send_entity
 from tiddlyweb.web.sendtiddlers import send_tiddlers
@@ -27,7 +28,7 @@ def delete(environ, start_response):
     How the store chooses to handle remove and what
     it means is up to the store.
     """
-    bag_name = _determine_bag_name(environ)
+    bag_name = web.get_route_value(environ, 'bag_name')
     bag_name = web.handle_extension(environ, bag_name)
 
     usersign = environ['tiddlyweb.usersign']
@@ -53,7 +54,7 @@ def get(environ, start_response):
     Get a representation in some serialization of
     a bag (the bag itself not the tiddlers within).
     """
-    bag_name = _determine_bag_name(environ)
+    bag_name = web.get_route_value(environ, 'bag_name')
     bag_name = web.handle_extension(environ, bag_name)
     bag = _get_bag(environ, bag_name)
 
@@ -69,7 +70,7 @@ def get_tiddlers(environ, start_response):
     serialization chosen.
     """
     store = environ['tiddlyweb.store']
-    bag_name = _determine_bag_name(environ)
+    bag_name = web.get_route_value(environ, 'bag_name')
     bag = _get_bag(environ, bag_name)
     title = 'Tiddlers From Bag %s' % bag.name
     title = environ['tiddlyweb.query'].get('title', [title])[0]
@@ -101,7 +102,7 @@ def put(environ, start_response):
     Put a bag to the server, meaning the description and
     policy of the bag, if policy allows.
     """
-    bag_name = _determine_bag_name(environ)
+    bag_name = web.get_route_value(environ, 'bag_name')
     bag_name = web.handle_extension(environ, bag_name)
 
     bag = Bag(bag_name)
@@ -150,17 +151,6 @@ def _validate_bag(environ, bag):
         raise HTTP409('Bag content is invalid: %s' % exc)
 
 
-def _determine_bag_name(environ):
-    """
-    Figure out the name of the target bag by
-    parsing the URL.
-    """
-    bag_name = environ['wsgiorg.routing_args'][1]['bag_name']
-    bag_name = urllib.unquote(bag_name)
-    bag_name = unicode(bag_name, 'utf-8')
-    return bag_name
-
-
 def _get_bag(environ, bag_name):
     """
     Get the named bag out of the store.
